Module: ApplicationService

Defined in:
lib/application_service.rb,
lib/application_service/version.rb,
sig/application_service.rbs

Overview

The ApplicationService module serves as a namespace for service objects. Service objects encapsulate business logic and are typically used to perform a single action or a series of related actions.

Defined Under Namespace

Classes: Base

Constant Summary collapse

VERSION =

Returns:

  • (String)
"0.6.3"